pub struct RecipesRequest {
pub threshold: u8,
}Expand description
How complete a match has to be to be worth reporting.
Not #[non_exhaustive]: consumers construct this.
Fields
threshold: u8The lowest percentage of a recipe’s ingredients that may be in stock for it to count as a partial match, as a whole number out of 100.